aboutsummaryrefslogtreecommitdiffstats
path: root/ci/build-vsperf.sh
diff options
context:
space:
mode:
authorMartin Klozik <martinx.klozik@intel.com>2017-06-06 15:02:07 +0100
committerMartin Klozik <martinx.klozik@intel.com>2017-06-06 17:02:48 +0100
commitd10939601932809da1d5ae717323ac33a72a0d75 (patch)
treefb3a5778ebf13b0a706468c2bb1004a127ca762d /ci/build-vsperf.sh
parent0975aa2ec9baf2e852be7991f62ba40865997456 (diff)
ci: Plot graphs from CI results
CI scripts were enhanced to plot graphs from last results and push them into artifactory. Graphs will be updated by every CI run and can be included e.g. in VSPERF results WIKI page. Change-Id: Iada4acd7cc2c3dc73b9f30a429fe2b53020c4d3b Signed-off-by: Martin Klozik <martinx.klozik@intel.com>
Diffstat (limited to 'ci/build-vsperf.sh')
-rwxr-xr-xci/build-vsperf.sh22
1 files changed, 19 insertions, 3 deletions
diff --git a/ci/build-vsperf.sh b/ci/build-vsperf.sh
index 5a3ed8c1..5cc4385e 100755
--- a/ci/build-vsperf.sh
+++ b/ci/build-vsperf.sh
@@ -1,6 +1,6 @@
#!/bin/bash
#
-# Copyright 2015-2016 Intel Corporation.
+# Copyright 2015-2017 Intel Corporation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
@@ -40,6 +40,7 @@ LOG_FILE_PREFIX="/tmp/vsperf_build"
DATE=$(date -u +"%Y-%m-%d_%H-%M-%S")
BRANCH=${GIT_BRANCH##*/}
VSPERFENV_DIR="$HOME/vsperfenv"
+RESULTS_ARCHIVE="$HOME/ci_results_archive"
# CI job specific configuration
# VERIFY - run basic set of TCs with default settings
@@ -282,8 +283,8 @@ function generate_report() {
# prepare final tarball with all logs...
tar --exclude "${TEST_REPORT_TARBALL}" -czf "${TEST_REPORT_LOG_DIR}/${TEST_REPORT_TARBALL}" $(find "${TEST_REPORT_LOG_DIR}" -mindepth 1 -maxdepth 1 -type d)
- # ...and remove original log files
- find "${TEST_REPORT_LOG_DIR}" -mindepth 1 -maxdepth 1 -type d -exec rm -rf \{\} \;
+ # ...and move original log files to the archive directory
+ find "${TEST_REPORT_LOG_DIR}" -mindepth 1 -maxdepth 1 -type d -exec mv \{\} ${RESULTS_ARCHIVE} \;
# clone opnfvdocs repository
echo "Cloning opnfvdocs repository..."
@@ -304,6 +305,19 @@ function generate_report() {
fi
}
+# generates graphs from recent test results
+function generate_and_push_graphs() {
+ # create graphs from results in archive directory
+ ./ci/plot-results.sh "phy2phy_tput back2back pvp_tput pvvp_tput" ",OvsDpdkVhost," $RESULTS_ARCHIVE
+
+ # push graphs into artifactory
+ if ls *png &> /dev/null ; then
+ gsutil cp *png gs://artifacts.opnfv.org/logs/vswitchperf/intel-pod12/graphs/
+ else
+ echo "Graphs were not created."
+ fi
+}
+
# pushes test report and logs collected during test execution into artifactory
function push_results_to_artifactory() {
# clone releng repository
@@ -507,6 +521,8 @@ case $1 in
push_results_to_artifactory
+ generate_and_push_graphs
+
cleanup
exit $EXIT